@@ -7,7 +7,6 @@
 
 """Query PubMed and print MEDLINE format results."""
 
-from __future__ import print_function
 
 import sys
 import getopt
@@ -17,7 +16,8 @@ from Bio import Entrez
 
 def print_usage():
     """Print a help message."""
-    print("""query_pubmed.py [-h] [-c] [-d delay] query
+    print(
+        """query_pubmed.py [-h] [-c] [-d delay] query
 
 This script sends a query to PubMed (via the NCBI Entrez webservice*)
 and prints the MEDLINE formatted results to the screen.
@@ -27,28 +27,29 @@ Arguments:
     -c           Count the hits, and don't print them out.
 
 * http://www.ncbi.nlm.nih.gov/Entrez/
-""")
+"""
+    )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     try:
         optlist, args = getopt.getopt(sys.argv[1:], "hcd:")
     except getopt.error as x:
         print(x)
         sys.exit(0)
-    if len(args) != 1:     # If they gave extraneous arguments,
-        print_usage()      # print the instructions and quit.
+    if len(args) != 1:  # If they gave extraneous arguments,
+        print_usage()  # print the instructions and quit.
         sys.exit(0)
     query = args[0]
 
     show_help = False
     count_only = False
     for opt, arg in optlist:
-        if opt == '-h':
+        if opt == "-h":
             show_help = True
-        elif opt == '-c':
+        elif opt == "-c":
             count_only = True
-        elif opt == '-d':
+        elif opt == "-d":
             sys.stderr.write("The delay parameter is now ignored\n")
     if show_help:
         print_usage()
@@ -63,7 +64,7 @@ if __name__ == '__main__':
     search_results = Entrez.read(handle)
     ids = search_results["IdList"]
     count = len(ids)
-    print("Found %d citations" % count)
+    print(f"Found {count:d} citations")
 
     if count_only:
         sys.exit(0)
@@ -74,10 +75,15 @@ if __name__ == '__main__':
     for start in range(0, count, batch_size):
         end = min(count, start + batch_size)
         # print("Going to download record %i to %i" % (start+1, end))
-        fetch_handle = Entrez.efetch(db="pubmed", rettype="medline",
-                                     retmode="text",
-                                     retstart=start, retmax=batch_size,
-                                     webenv=webenv, query_key=query_key)
+        fetch_handle = Entrez.efetch(
+            db="pubmed",
+            rettype="medline",
+            retmode="text",
+            retstart=start,
+            retmax=batch_size,
+            webenv=webenv,
+            query_key=query_key,
+        )
         data = fetch_handle.read()
         fetch_handle.close()
         sys.stdout.write(data)
