@@ -4,9 +4,6 @@
 
 """Common code for SeqRecord object tests."""
 
-from Bio._py3k import range
-from Bio._py3k import basestring
-
 from Bio.Seq import UnknownSeq
 from Bio.SeqUtils.CheckSum import seguid
 from Bio.SeqFeature import ExactPosition, UnknownPosition
@@ -243,14 +240,14 @@ def compare_record(old, new):
     # 'ncbi_taxon' and 'gi'.
     # TODO - address these, see Bug 2681?
     new_keys = set(new.annotations).difference(old.annotations)
-    new_keys = new_keys.difference(['cross_references', 'date',
-                                    'data_file_division', 'ncbi_taxid',
-                                    'gi'])
+    new_keys = new_keys.difference(["cross_references", "date",
+                                    "data_file_division", "ncbi_taxid",
+                                    "gi"])
     assert not new_keys, "Unexpected new annotation keys: %s" \
         % ", ".join(new_keys)
     missing_keys = set(old.annotations).difference(new.annotations)
-    missing_keys = missing_keys.difference(['ncbi_taxid',  # Can't store chimeras
-                                            'structured_comment'])
+    missing_keys = missing_keys.difference(["ncbi_taxid",  # Can't store chimeras
+                                            "structured_comment"])
     assert not missing_keys, "Unexpectedly missing annotation keys: %s" \
         % ", ".join(missing_keys)
 
@@ -275,14 +272,13 @@ def compare_record(old, new):
             old_comment = old_comment.replace("\n", " ").replace("  ", " ")
             new_comment = new_comment.replace("\n", " ").replace("  ", " ")
             assert old_comment == new_comment, \
-                "Comment annotation changed by load/retrieve\n" \
-                "Was:%s\nNow:%s" \
-                % (repr(old_comment), repr(new_comment))
+                ("Comment annotation changed by load/retrieve\n"
+                 "Was:%s\nNow:%s" % (repr(old_comment), repr(new_comment)))
         elif key in ["taxonomy", "organism", "source"]:
             # If there is a taxon id recorded, these fields get overwritten
             # by data from the taxon/taxon_name tables.  There is no
             # guarantee that they will be identical after a load/retrieve.
-            assert isinstance(new.annotations[key], basestring) \
+            assert isinstance(new.annotations[key], str) \
                 or isinstance(new.annotations[key], list)
         elif isinstance(old.annotations[key], type(new.annotations[key])):
             assert old.annotations[key] == new.annotations[key], \
