@@ -15,14 +15,19 @@ from BioSQL import BioSeqDatabase
 from common_BioSQL import *  # noqa: F403
 
 # Import these explicitly to avoid flake8 F405 below:
-from common_BioSQL import load_biosql_ini, check_config, compare_records, temp_db_filename
+from common_BioSQL import (
+    load_biosql_ini,
+    check_config,
+    compare_records,
+    temp_db_filename,
+)
 
 # Constants for the database driver
-DBDRIVER = 'sqlite3'
-DBTYPE = 'sqlite'
+DBDRIVER = "sqlite3"
+DBTYPE = "sqlite"
 
 DBHOST = None
-DBUSER = 'root'
+DBUSER = "root"
 DBPASSWD = None
 TESTDB = temp_db_filename()
 
@@ -36,8 +41,7 @@ if False:
     # catch any regressions in how we map GenBank entries to
     # the database.
     assert not os.path.isfile("BioSQL/cor6_6.db")
-    server = BioSeqDatabase.open_database(driver=DBDRIVER,
-                                          db="BioSQL/cor6_6.db")
+    server = BioSeqDatabase.open_database(driver=DBDRIVER, db="BioSQL/cor6_6.db")
     DBSCHEMA = "biosqldb-" + DBTYPE + ".sql"
     SQL_FILE = os.path.join(os.getcwd(), "BioSQL", DBSCHEMA)
     assert os.path.isfile(SQL_FILE), SQL_FILE
@@ -56,13 +60,11 @@ class BackwardsCompatibilityTest(unittest.TestCase):
         """Check can re-use an old BioSQL SQLite3 database."""
         original_records = list(SeqIO.parse("GenBank/cor6_6.gb", "gb"))
         # now open a connection to load the database
-        server = BioSeqDatabase.open_database(driver=DBDRIVER,
-                                              db="BioSQL/cor6_6.db")
+        server = BioSeqDatabase.open_database(driver=DBDRIVER, db="BioSQL/cor6_6.db")
         db = server["OLD"]
         self.assertEqual(len(db), len(original_records))
         # Now read them back...
-        biosql_records = [db.lookup(name=rec.name)
-                          for rec in original_records]
+        biosql_records = [db.lookup(name=rec.name) for rec in original_records]
         # And check they agree
         # Note the old parser used to create BioSQL/cor6_6.db
         # did not record the molecule_type, so remove it here:
