@@ -16,14 +16,15 @@ from common_BioSQL import load_biosql_ini, check_config, temp_db_filename
 from common_BioSQL_online import share_config
 
 import requires_internet
+
 requires_internet.check()
 
 # Constants for the database driver
-DBDRIVER = 'sqlite3'
-DBTYPE = 'sqlite'
+DBDRIVER = "sqlite3"
+DBTYPE = "sqlite"
 
 DBHOST = None
-DBUSER = 'root'
+DBUSER = "root"
 DBPASSWD = None
 TESTDB = temp_db_filename()
 
