@@ -5,9 +5,6 @@
 
 """Tests for Muscle tool."""
 
-from __future__ import print_function
-from Bio._py3k import _universal_read_mode
-
 import os
 import sys
 import subprocess
@@ -22,7 +19,7 @@ from Bio import AlignIO
 #################################################################
 
 # Try to avoid problems when the OS is in another language
-os.environ['LANG'] = 'C'
+os.environ["LANG"] = "C"
 
 muscle_exe = None
 if sys.platform == "win32":
@@ -50,13 +47,13 @@ if sys.platform == "win32":
         if muscle_exe:
             break
 else:
-    from Bio._py3k import getoutput
+    from subprocess import getoutput
     output = getoutput("muscle -version")
     # Since "not found" may be in another language, try and be sure this is
     # really the MUSCLE tool's output
-    if "not found" not in output and "MUSCLE" in output \
-       and "Edgar" in output:
-        muscle_exe = "muscle"
+    if "not found" not in output and "not recognized" not in output:
+        if "MUSCLE" in output and "Edgar" in output:
+            muscle_exe = "muscle"
 
 if not muscle_exe:
     raise MissingExternalDependencyError(
@@ -184,6 +181,35 @@ class SimpleAlignTest(unittest.TestCase):
             self.assertEqual(str(new.seq).replace("-",""), str(old.seq))
     """
 
+    def test_simple_msf(self):
+        """Simple muscle call using MSF output."""
+        input_file = "Fasta/f002"
+        self.assertTrue(os.path.isfile(input_file))
+        records = list(SeqIO.parse(input_file, "fasta"))
+        records.sort(key=lambda rec: rec.id)  # noqa: E731
+        cmdline = MuscleCommandline(muscle_exe, input=input_file, msf=True)
+        self.assertEqual(str(cmdline).rstrip(), _escape_filename(muscle_exe) +
+                         " -in Fasta/f002 -msf")
+        self.assertEqual(str(eval(repr(cmdline))), str(cmdline))
+        child = subprocess.Popen(str(cmdline),
+                                 stdout=subprocess.PIPE,
+                                 stderr=subprocess.PIPE,
+                                 universal_newlines=True,
+                                 shell=(sys.platform != "win32"))
+        # Didn't use -quiet so there should be progress reports on stderr,
+        align = AlignIO.read(child.stdout, "msf")
+        align.sort()  # by record.id
+        self.assertTrue(child.stderr.read().strip().startswith("MUSCLE"))
+        return_code = child.wait()
+        self.assertEqual(return_code, 0)
+        child.stdout.close()
+        child.stderr.close()
+        del child
+        self.assertEqual(len(records), len(align))
+        for old, new in zip(records, align):
+            self.assertEqual(old.id, new.id)
+            self.assertEqual(str(new.seq).replace("-", ""), str(old.seq))
+
     def test_simple_clustal(self):
         """Simple muscle call using Clustal output with a MUSCLE header."""
         input_file = "Fasta/f002"
@@ -355,7 +381,7 @@ class SimpleAlignTest(unittest.TestCase):
         child.stdout.close()
         child.stderr.close()
         del child
-        handle = open(output_html, _universal_read_mode)
+        handle = open(output_html)
         html = handle.read().strip().upper()
         handle.close()
         self.assertTrue(html.startswith("<HTML"))
