@@ -24,7 +24,7 @@ try:
                           stderr=subprocess.STDOUT)
 except OSError:
     raise MissingExternalDependencyError(
-        "Install naccess if you want to use it from Biopython.")
+        "Install naccess if you want to use it from Biopython.") from None
 
 
 class NACCESS_test(unittest.TestCase):
@@ -39,6 +39,6 @@ class NACCESS_test(unittest.TestCase):
         self.assertEqual(len(naccess), 66)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
