@@ -5,7 +5,6 @@
 
 """Test GenePop."""
 
-from __future__ import print_function
 
 import os
 import unittest
@@ -17,16 +16,17 @@ from Bio.PopGen.GenePop.Controller import GenePopController
 # test_PopGen_GenePop_nodepend tests code that does not require genepop
 
 found = False
-for path in os.environ['PATH'].split(os.pathsep):
+for path in os.environ["PATH"].split(os.pathsep):
     try:
         for filename in os.listdir(path):
-            if filename.startswith('Genepop'):
+            if filename.startswith("Genepop"):
                 found = True
     except os.error:
         pass  # Path doesn't exist - correct to pass
 if not found:
     raise MissingExternalDependencyError(
-        "Install GenePop if you want to use Bio.PopGen.GenePop.")
+        "Install GenePop if you want to use Bio.PopGen.GenePop."
+    )
 
 
 class AppTest(unittest.TestCase):
@@ -35,7 +35,8 @@ class AppTest(unittest.TestCase):
     def test_allele_genotype_frequencies(self):
         """Test genepop execution on basic allele and genotype frequencies."""
         ctrl = GenePopController()
-        pop_iter, locus_iter = ctrl.calc_allele_genotype_freqs("PopGen" + os.sep + "big.gen")
+        path = os.path.join("PopGen", "big.gen")
+        pop_iter, locus_iter = ctrl.calc_allele_genotype_freqs(path)
         # print("%s %s" % (pop, loci))
         # for popc in pop_iter:
         #    pop_name, loci_content = popc
@@ -51,39 +52,45 @@ class AppTest(unittest.TestCase):
     def test_calc_diversities_fis_with_identity(self):
         """Test calculations of diversities."""
         ctrl = GenePopController()
-        iter, avg_fis, avg_Qintra = ctrl.calc_diversities_fis_with_identity(
-            "PopGen" + os.sep + "big.gen")
+        path = os.path.join("PopGen", "big.gen")
+        iter, avg_fis, avg_Qintra = ctrl.calc_diversities_fis_with_identity(path)
         liter = list(iter)
-        assert len(liter) == 37
-        assert liter[0][0] == "Locus1"
-        assert len(avg_fis) == 10
-        assert len(avg_Qintra) == 10
+        self.assertEqual(len(liter), 37)
+        self.assertEqual(liter[0][0], "Locus1")
+        self.assertEqual(len(avg_fis), 10)
+        self.assertEqual(len(avg_Qintra), 10)
 
     def test_estimate_nm(self):
         """Test Nm estimation."""
         ctrl = GenePopController()
-        mean_sample_size, mean_priv_alleles, mig10, mig25, mig50, mig_corrected =\
-            ctrl.estimate_nm("PopGen" + os.sep + "big.gen")
-        assert (mean_sample_size, mean_priv_alleles, mig10, mig25, mig50, mig_corrected) == \
-               (28.0, 0.016129, 52.5578, 15.3006, 8.94583, 13.6612)
+        path = os.path.join("PopGen", "big.gen")
+        mean_sample_size, mean_priv_alleles, mig10, mig25, mig50, mig_corrected = ctrl.estimate_nm(path)
+        self.assertAlmostEqual(mean_sample_size, 28.0)
+        self.assertAlmostEqual(mean_priv_alleles, 0.016129)
+        self.assertAlmostEqual(mig10, 52.5578)
+        self.assertAlmostEqual(mig25, 15.3006)
+        self.assertAlmostEqual(mig50, 8.94583)
+        self.assertAlmostEqual(mig_corrected, 13.6612)
 
     def test_fst_all(self):
         """Test genepop execution on all fst."""
         ctrl = GenePopController()
-        (allFis, allFst, allFit), itr = ctrl.calc_fst_all("PopGen" + os.sep + "c2line.gen")
+        path = os.path.join("PopGen", "c2line.gen")
+        (allFis, allFst, allFit), itr = ctrl.calc_fst_all(path)
         results = list(itr)
-        assert (len(results) == 3)
-        assert (results[0][0] == "136255903")
-        assert (results[1][3] - 0.33 < 0.01)
+        self.assertEqual(len(results), 3)
+        self.assertEqual(results[0][0], "136255903")
+        self.assertAlmostEqual(results[1][3], 0.335846)
 
     def test_haploidy(self):
         """Test haploidy."""
         ctrl = GenePopController()
-        (allFis, allFst, allFit), itr = ctrl.calc_fst_all("PopGen" + os.sep + "haplo.gen")
+        path = os.path.join("PopGen", "haplo.gen")
+        (allFis, allFst, allFit), itr = ctrl.calc_fst_all(path)
         litr = list(itr)
-        assert not isinstance(allFst, int)
-        assert len(litr) == 37
-        assert litr[36][0] == "Locus37"
+        self.assertNotIsInstance(allFst, int)
+        self.assertEqual(len(litr), 37)
+        self.assertEqual(litr[36][0], "Locus37")
 
 
 if __name__ == "__main__":
