@@ -1,10 +1,7 @@
-"""
-Unittests for Bio.Align.Applications interface for PRANK
-
-This code is part of the Biopython distribution and governed by its
-license.  Please see the LICENSE file that should have been included
-as part of this package.
-"""
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
+"""Unittests for Bio.Align.Applications interface for PRANK."""
 
 import sys
 import os
@@ -17,7 +14,7 @@ from Bio.Align.Applications import PrankCommandline
 from Bio.Nexus.Nexus import NexusError
 
 # Try to avoid problems when the OS is in another language
-os.environ['LANG'] = 'C'
+os.environ["LANG"] = "C"
 
 prank_exe = None
 if sys.platform == "win32":
@@ -40,10 +37,11 @@ if sys.platform == "win32":
         if prank_exe:
             break
 else:
-    from Bio._py3k import getoutput
+    from subprocess import getoutput
     output = getoutput("prank")
-    if "not found" not in output and "prank" in output.lower():
-        prank_exe = "prank"
+    if "not found" not in output and "not recognized" not in output:
+        if "prank" in output.lower():
+            prank_exe = "prank"
 if not prank_exe:
     raise MissingExternalDependencyError(
         "Install PRANK if you want to use the Bio.Align.Applications wrapper.")
@@ -55,7 +53,8 @@ class PrankApplication(unittest.TestCase):
         self.infile1 = "Fasta/fa01"
 
     def tearDown(self):
-        """
+        """Remove generated files.
+
         output.1.dnd  output.1.fas  output.1.xml  output.2.dnd  output.2.fas  output.2.xml
         """
         if os.path.isfile("output.1.dnd"):
@@ -77,6 +76,7 @@ class PrankApplication(unittest.TestCase):
 
     def test_Prank_simple(self):
         """Simple round-trip through app with infile.
+
         output.?.??? files written to cwd - no way to redirect
         """
         cmdline = PrankCommandline(prank_exe)
@@ -86,10 +86,11 @@ class PrankApplication(unittest.TestCase):
         self.assertEqual(str(eval(repr(cmdline))), str(cmdline))
         output, error = cmdline()
         self.assertEqual(error, "")
-        self.assertTrue("Total time" in output)
+        self.assertIn("Total time", output)
 
     def test_Prank_simple_with_NEXUS_output(self):
-        """Simple round-trip through app with infile, output in NEXUS
+        """Simple round-trip through app with infile, output in NEXUS.
+
         output.?.??? files written to cwd - no way to redirect
         """
         records = list(SeqIO.parse(self.infile1, "fasta"))
@@ -103,7 +104,7 @@ class PrankApplication(unittest.TestCase):
                          " -d=Fasta/fa01 -f=17 -dots")
         self.assertEqual(str(eval(repr(cmdline))), str(cmdline))
         stdout, stderr = cmdline()
-        self.assertTrue("Total time" in stdout)
+        self.assertIn("Total time", stdout)
         self.assertEqual(stderr, "")
         try:
             if os.path.isfile("output.best.nex"):
@@ -144,14 +145,14 @@ class PrankApplication(unittest.TestCase):
                          " -once -skipins -realbranches")
         self.assertEqual(str(eval(repr(cmdline))), str(cmdline))
         stdout, stderr = cmdline()
-        self.assertTrue("Total time" in stdout, stdout)
+        self.assertIn("Total time", stdout)
 
 
 class PrankConversion(unittest.TestCase):
     def setUp(self):
         # As these reads are all 36, it can be seen as pre-aligned:
         self.input = "Quality/example.fasta"
-        self.output = 'temp with space'  # prefix, PRANK will pick extensions
+        self.output = "temp with space"  # prefix, PRANK will pick extensions
 
     def conversion(self, prank_number, prank_ext, format):
         """Get PRANK to do a conversion, and check it with SeqIO."""
@@ -162,13 +163,13 @@ class PrankConversion(unittest.TestCase):
                                    convert=True, f=prank_number,
                                    o='"%s"' % self.output)
         self.assertEqual(str(cmdline), _escape_filename(prank_exe) +
-                         ' -d=%s' % self.input +
+                         " -d=%s" % self.input +
                          ' -o="%s"' % self.output +
-                         ' -f=%i' % prank_number +
-                         ' -convert')
+                         " -f=%i" % prank_number +
+                         " -convert")
         self.assertEqual(str(eval(repr(cmdline))), str(cmdline))
         message, error = cmdline()
-        self.assertTrue("PRANK" in message, message)
+        self.assertIn("PRANK", message)
         self.assertTrue(("converting '%s' to '%s'" % (self.input, filename))
                         in message, message)
         self.assertEqual(error, "")
