@@ -17,7 +17,7 @@ try:
 except ImportError:
     from Bio import MissingPythonDependencyError
     raise MissingPythonDependencyError(
-        "Install NumPy if you want to use PDB formats with SeqIO.")
+        "Install NumPy if you want to use PDB formats with SeqIO.") from None
 
 from Bio import SeqIO
 from Bio import BiopythonParserWarning
@@ -36,6 +36,7 @@ def SeqresTestGenerator(extension, parser):
             ``pdb`` or ``cif``).
         parser:
             The name of the SeqIO parser to use (e.g. ``pdb-atom``).
+
     """
     class SeqresTests(unittest.TestCase):
         """Use "parser" to parse sequence records from a structure file.
@@ -43,6 +44,7 @@ def SeqresTestGenerator(extension, parser):
         Args:
             parser (str): Name of the parser used by SeqIO.
             extension (str): Extension of the files to parse.
+
         """
 
         def test_seqres_parse(self):
@@ -51,12 +53,12 @@ def SeqresTestGenerator(extension, parser):
             Reference:
             http://www.rcsb.org/pdb/files/fasta.txt?structureIdList=2BEG
             """
-            chains = list(SeqIO.parse('PDB/2BEG.' + extension, parser))
+            chains = list(SeqIO.parse("PDB/2BEG." + extension, parser))
             self.assertEqual(len(chains), 5)
-            actual_seq = 'DAEFRHDSGYEVHHQKLVFFAEDVGSNKGAIIGLMVGGVVIA'
-            for chain, chn_id in zip(chains, 'ABCDE'):
-                self.assertEqual(chain.id, '2BEG:' + chn_id)
-                self.assertEqual(chain.annotations['chain'], chn_id)
+            actual_seq = "DAEFRHDSGYEVHHQKLVFFAEDVGSNKGAIIGLMVGGVVIA"
+            for chain, chn_id in zip(chains, "ABCDE"):
+                self.assertEqual(chain.id, "2BEG:" + chn_id)
+                self.assertEqual(chain.annotations["chain"], chn_id)
                 self.assertEqual(str(chain.seq), actual_seq)
 
         def test_seqres_read(self):
@@ -65,16 +67,16 @@ def SeqresTestGenerator(extension, parser):
             Reference:
             http://www.rcsb.org/pdb/files/fasta.txt?structureIdList=1A8O
             """
-            chain = SeqIO.read('PDB/1A8O.' + extension, parser)
-            self.assertEqual(chain.id, '1A8O:A')
-            self.assertEqual(chain.annotations['chain'], 'A')
+            chain = SeqIO.read("PDB/1A8O." + extension, parser)
+            self.assertEqual(chain.id, "1A8O:A")
+            self.assertEqual(chain.annotations["chain"], "A")
             self.assertEqual(str(chain.seq),
-                             'MDIRQGPKEPFRDYVDRFYKTLRAEQASQEVKNWMTETLLVQNANPD'
-                             'CKTILKALGPGATLEEMMTACQG')
+                             "MDIRQGPKEPFRDYVDRFYKTLRAEQASQEVKNWMTETLLVQNANPD"
+                             "CKTILKALGPGATLEEMMTACQG")
 
         def test_seqres_missing(self):
             """Parse a PDB with no SEQRES entries."""
-            chains = list(SeqIO.parse('PDB/a_structure.' + extension, parser))
+            chains = list(SeqIO.parse("PDB/a_structure." + extension, parser))
             self.assertEqual(len(chains), 0)
     return SeqresTests
 
@@ -103,24 +105,26 @@ def AtomTestGenerator(extension, parser):
             Reference:
             http://www.rcsb.org/pdb/files/fasta.txt?structureIdList=2BEG
             """
-            chains = list(SeqIO.parse('PDB/2BEG.' + extension, parser))
+            chains = list(SeqIO.parse("PDB/2BEG." + extension, parser))
             self.assertEqual(len(chains), 5)
-            actual_seq = 'LVFFAEDVGSNKGAIIGLMVGGVVIA'
-            for chain, chn_id in zip(chains, 'ABCDE'):
-                self.assertEqual(chain.id, '2BEG:' + chn_id)
-                self.assertEqual(chain.annotations['chain'], chn_id)
-                self.assertEqual(chain.annotations['model'], 0)
+            actual_seq = "LVFFAEDVGSNKGAIIGLMVGGVVIA"
+            for chain, chn_id in zip(chains, "ABCDE"):
+                self.assertEqual(chain.id, "2BEG:" + chn_id)
+                self.assertEqual(chain.annotations["chain"], chn_id)
+                self.assertEqual(chain.annotations["model"], 0)
                 self.assertEqual(str(chain.seq), actual_seq)
 
             with warnings.catch_warnings():
                 warnings.simplefilter("ignore", PDBConstructionWarning)
-                chains = list(SeqIO.parse('PDB/2XHE.' + extension, parser))
-            actual_seq = 'DRLSRLRQMAAENQXXXXXXXXXXXXXXXXXXXXXXXPEPFMADFFNRVK'\
-                         'RIRDNIEDIEQAIEQVAQLHTESLVAVSKEDRDRLNEKLQDTMARISALG'\
-                         'NKIRADLKQIEKENKRAQQEGTFEDGTVSTDLRIRQSQHSSLSRKFVKVM'\
-                         'TRYNDVQAENKRRYGENVARQCRVVEPSLSDDAIQKVIEHGXXXXXXXXX'\
-                         'XXXXXXXXNEIRDRHKDIQQLERSLLELHEMFTDMSTLVASQGEMIDRIE'\
-                         'FSVEQSHNYV'
+                chains = list(SeqIO.parse("PDB/2XHE." + extension, parser))
+            actual_seq = (
+                "DRLSRLRQMAAENQXXXXXXXXXXXXXXXXXXXXXXXPEPFMADFFNRVK"
+                "RIRDNIEDIEQAIEQVAQLHTESLVAVSKEDRDRLNEKLQDTMARISALG"
+                "NKIRADLKQIEKENKRAQQEGTFEDGTVSTDLRIRQSQHSSLSRKFVKVM"
+                "TRYNDVQAENKRRYGENVARQCRVVEPSLSDDAIQKVIEHGXXXXXXXXX"
+                "XXXXXXXXNEIRDRHKDIQQLERSLLELHEMFTDMSTLVASQGEMIDRIE"
+                "FSVEQSHNYV"
+            )
             self.assertEqual(str(chains[1].seq), actual_seq)
 
         def test_atom_read(self):
@@ -129,42 +133,47 @@ def AtomTestGenerator(extension, parser):
             Reference:
             http://www.rcsb.org/pdb/files/fasta.txt?structureIdList=1A8O
             """
-            chain = SeqIO.read('PDB/1A8O.' + extension, parser)
-            self.assertEqual(chain.id, '1A8O:A')
-            self.assertEqual(chain.annotations['chain'], 'A')
-            self.assertEqual(chain.annotations['model'], 0)
+            chain = SeqIO.read("PDB/1A8O." + extension, parser)
+            self.assertEqual(chain.id, "1A8O:A")
+            self.assertEqual(chain.annotations["chain"], "A")
+            self.assertEqual(chain.annotations["model"], 0)
             self.assertEqual(str(chain.seq),
-                             'MDIRQGPKEPFRDYVDRFYKTLRAEQASQEVKNWMTETLLVQNANPDCKTIL'
-                             'KALGPGATLEEMMTACQG')
+                             "MDIRQGPKEPFRDYVDRFYKTLRAEQASQEVKNWMTETLLVQNANPDCKTIL"
+                             "KALGPGATLEEMMTACQG")
 
     return AtomTests
 
 
-class TestPdbAtom(AtomTestGenerator('pdb', 'pdb-atom')):
+class TestPdbAtom(AtomTestGenerator("pdb", "pdb-atom")):
     """Test pdb-atom SeqIO driver."""
 
     def test_atom_noheader(self):
         """Parse a PDB with no HEADER line."""
         with warnings.catch_warnings():
-            warnings.simplefilter('ignore', PDBConstructionWarning)
+            warnings.simplefilter("ignore", PDBConstructionWarning)
             warnings.simplefilter("ignore", BiopythonParserWarning)
-            chains = list(SeqIO.parse('PDB/1LCD.pdb', 'pdb-atom'))
+            chains = list(SeqIO.parse("PDB/1LCD.pdb", "pdb-atom"))
 
         self.assertEqual(len(chains), 1)
-        self.assertEqual(str(chains[0].seq), 'MKPVTLYDVAEYAGVSYQTVSRVVNQASHVSAKTREKVEAAMAELNYIPNR')
+        self.assertEqual(str(chains[0].seq), "MKPVTLYDVAEYAGVSYQTVSRVVNQASHVSAKTREKVEAAMAELNYIPNR")
 
     def test_atom_read_noheader(self):
         """Read a single-chain PDB without a header by ATOM entries."""
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", PDBConstructionWarning)
             warnings.simplefilter("ignore", BiopythonParserWarning)
-            chain = SeqIO.read('PDB/a_structure.pdb', 'pdb-atom')
-        self.assertEqual(chain.id, '????:A')
-        self.assertEqual(chain.annotations['chain'], 'A')
-        self.assertEqual(str(chain.seq), 'E')
+            chain = SeqIO.read("PDB/a_structure.pdb", "pdb-atom")
+        self.assertEqual(chain.id, "????:A")
+        self.assertEqual(chain.annotations["chain"], "A")
+        self.assertEqual(str(chain.seq), "E")
+
+    def test_atom_with_insertion(self):
+        """Read a PDB with residue insertion code."""
+        chain = SeqIO.read("PDB/2n0n_M1.pdb", "pdb-atom")
+        self.assertEqual(str(chain.seq), "HAEGKFTSEF")
 
 
-class TestCifAtom(AtomTestGenerator('cif', 'cif-atom')):
+class TestCifAtom(AtomTestGenerator("cif", "cif-atom")):
     """Test cif-atom SeqIO driver."""
 
     def test_atom_read_noheader(self):
@@ -172,12 +181,12 @@ class TestCifAtom(AtomTestGenerator('cif', 'cif-atom')):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", PDBConstructionWarning)
             warnings.simplefilter("ignore", BiopythonParserWarning)
-            chain = SeqIO.read('PDB/a_structure.cif', 'cif-atom')
-        self.assertEqual(chain.id, '????:A')
-        self.assertEqual(chain.annotations['chain'], 'A')
+            chain = SeqIO.read("PDB/a_structure.cif", "cif-atom")
+        self.assertEqual(chain.id, "????:A")
+        self.assertEqual(chain.annotations["chain"], "A")
         self.assertEqual(str(chain.seq),
-                         'MDIRQGPKEPFRDYVDRFYKTLRAEQASQEVKNWMTETLLVQNANPDCKTIL'
-                         'KALGPGATLEEMMTACQG')
+                         "MDIRQGPKEPFRDYVDRFYKTLRAEQASQEVKNWMTETLLVQNANPDCKTIL"
+                         "KALGPGATLEEMMTACQG")
 
 
 if __name__ == "__main__":
