@@ -6,18 +6,17 @@
 
 try:
     import numpy
+
     del numpy
 except ImportError:
     from Bio import MissingExternalDependencyError
-    raise MissingExternalDependencyError(
-        "Install NumPy if you want to use Bio.SubsMat.")
 
-try:
-    import cPickle as pickle  # Only available on Python 2
-except ImportError:
-    import pickle
+    raise MissingExternalDependencyError(
+        "Install NumPy if you want to use Bio.SubsMat."
+    )
 
 import os
+import pickle
 import unittest
 
 
@@ -26,7 +25,6 @@ from Bio.SubsMat import FreqTable, MatrixInfo
 
 
 class TestGeo(unittest.TestCase):
-
     @classmethod
     def setUpClass(cls):
         ftab_file = os.path.join("SubsMat", "protein_count.txt")
@@ -275,7 +273,9 @@ class TestGeo(unittest.TestCase):
 
     def test_observed_frequency_to_substitution_matrix(self):
         of_to_sm = SubsMat.observed_frequency_to_substitution_matrix(self.obs_freq_mat)
-        self.assertEqual(str(of_to_sm), """\
+        self.assertEqual(
+            str(of_to_sm),
+            """\
 A   1
 C   0   8
 D   0   0   2
@@ -296,7 +296,8 @@ T   1   0   0   1   0   0   1   0   1   0   0   1   0   1   1   1   1
 V   0   1   0   0   1   0   0   1   0   1   1   0   0   0   0   0   0   1
 W   0   0   0   0   1   0   0   1   0   1   1   0   0   0   0   0   0   0   6
 Y   0   0   0   0   1   0   1   0   0   1   1   0   0   0   0   0   0   1   1   2
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
 
     def test_obs_freq_mat_sum(self):
         counts = self.obs_freq_mat.sum()
@@ -323,10 +324,13 @@ Y   0   0   0   0   1   0   1   0   0   1   1   0   0   0   0   0   0   1   1
         self.assertAlmostEqual(counts["Y"], 0.0420, places=3)
 
     def test_log_odds_matris(self):
-        lo_mat_prot = SubsMat.make_log_odds_matrix(acc_rep_mat=self.acc_rep_mat,
-                                                   round_digit=1)
+        lo_mat_prot = SubsMat.make_log_odds_matrix(
+            acc_rep_mat=self.acc_rep_mat, round_digit=1
+        )
         text = lo_mat_prot.format(fmt=" %d", alphabet="AVILMCFWYHSTNQKRDEGP")
-        self.assertEqual(text, """\
+        self.assertEqual(
+            text,
+            """\
 A 0
 V 0 1
 I 0 0 1
@@ -347,9 +351,12 @@ D 0 0 -1 0 -1 -1 0 0 0 0 0 0 0 0 0 0 1
 E 0 0 -1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0 1
 G 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1
 P 0 0 0 -1 -1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1
-   A   V   I   L   M   C   F   W   Y   H   S   T   N   Q   K   R   D   E   G   P""")
+   A   V   I   L   M   C   F   W   Y   H   S   T   N   Q   K   R   D   E   G   P""",
+        )
         text = lo_mat_prot.format(fmt=" %d", alphabet="AVILMCFWYHSTNQKRDEGP", full=True)
-        self.assertEqual(text, """\
+        self.assertEqual(
+            text,
+            """\
    A   V   I   L   M   C   F   W   Y   H   S   T   N   Q   K   R   D   E   G   P
 A 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 V 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
@@ -370,7 +377,8 @@ R 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0
 D 0 0 -1 0 -1 -1 0 0 0 0 0 0 0 0 0 0 1 0 0 0
 E 0 0 -1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0 1 0 0
 G 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0
-P 0 0 0 -1 -1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1""")
+P 0 0 0 -1 -1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1""",
+        )
         relative_entropy = lo_mat_prot.calculate_relative_entropy(self.obs_freq_mat)
         self.assertAlmostEqual(relative_entropy, 0.162, places=3)
 
@@ -378,7 +386,9 @@ P 0 0 0 -1 -1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1""")
         self.assertEqual(len(MatrixInfo.available_matrices), 40)
         mat = SubsMat.SeqMat(MatrixInfo.benner6)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   2
 C  -1  12
 D   0  -3   5
@@ -399,10 +409,13 @@ T   1  -1  -1  -1  -2   0  -1   0  -1   0   0   0   0  -1  -1   1   2
 V   0  -3  -3  -3   0  -2  -3   3  -3   1   3  -2  -1  -3  -3   0   0   4
 W  -4   1  -6  -5  -1  -1  -2  -5  -1  -3  -4  -4  -4  -2   2  -2  -2  -4  14
 Y  -4   2  -2  -4   5  -4   4  -3  -4  -1  -3   0  -3  -1  -2  -1  -3  -3   0   9
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.benner22)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   2
 C  -1  12
 D   0  -3   4
@@ -423,10 +436,13 @@ T   1  -1   0   0  -2   0  -1   0   0  -1   0   0   0   0   0   1   2
 V   0  -1  -3  -2   0  -2  -3   3  -2   2   2  -2  -1  -2  -2   0   0   3
 W  -5   0  -6  -6   0  -4  -2  -4  -3  -1  -2  -5  -5  -3  -1  -3  -4  -4  15
 Y  -3   0  -3  -4   5  -4   3  -2  -3   0  -1  -1  -3  -1  -2  -1  -3  -2   1   9
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.benner74)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   2
 C   0  11
 D   0  -3   4
@@ -447,10 +463,13 @@ T   0   0   0   0  -2  -1   0   0   0  -1   0   0   0   0   0   1   2
 V   0   0  -2  -2   0  -3  -2   3  -1   1   1  -2  -1  -1  -2  -1   0   3
 W  -4   0  -5  -4   3  -4  -1  -2  -3   0  -1  -4  -5  -2  -1  -3  -3  -2  14
 Y  -2   0  -2  -3   5  -4   2  -1  -2   0   0  -1  -3  -1  -2  -1  -2  -1   3   8
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum100)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -3   4
 C  -1  -5   9
@@ -474,10 +493,13 @@ W  -4  -6  -5  -7  -5   0  -5  -3  -4  -5  -4  -3  -6  -6  -3  -4  -4  -5  -4  1
 X  -1  -2  -3  -3  -2  -3  -3  -2  -2  -2  -2  -2  -2  -3  -2  -2  -1  -1  -2  -4  -2
 Y  -4  -4  -4  -5  -4   3  -6   1  -3  -4  -3  -3  -3  -5  -3  -3  -3  -3  -3   1  -3   8
 Z  -2   1  -6   0   5  -5  -4  -1  -4   0  -4  -3  -1  -3   3  -1  -1  -2  -3  -4  -2  -4   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum30)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 B   0   5
 C  -3  -2  17
@@ -501,10 +523,13 @@ W  -5  -5  -2  -4  -1   1   1  -5  -3  -2  -2  -3  -7  -3  -1   0  -3  -5  -3  2
 X   0  -1  -2  -1  -1  -1  -1  -1   0   0   0   0   0  -1   0  -1   0   0   0  -2  -1
 Y  -4  -3  -6  -1  -2   3  -3   0  -1  -1   3  -1  -4  -2  -1   0  -2  -1   1   5  -1   9
 Z   0   0   0   0   5  -4  -2   0  -3   1  -1  -1  -1   0   4   0  -1  -1  -3  -1   0  -2   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum35)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -1   5
 C  -2  -2  15
@@ -528,10 +553,13 @@ W  -2  -3  -5  -3  -1   1  -1  -4  -1   0   0   1  -2  -4  -1   0  -2  -2  -2  1
 X   0  -1  -2  -1  -1  -1  -1  -1   0   0   0   0   0  -1  -1  -1   0   0   0  -1  -1
 Y  -1  -2  -5  -2  -1   3  -2   0   0  -1   0   0  -2  -3   0   0  -1  -2   0   3  -1   8
 Z  -1   0  -2   1   5  -3  -2  -1  -3   1  -2  -2   0   0   4   0   0  -1  -2  -1   0  -1   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum40)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -1   5
 C  -2  -2  16
@@ -555,10 +583,13 @@ W  -3  -4  -6  -5  -2   1  -2  -5  -3  -2  -1  -2  -4  -4  -1  -2  -5  -4  -3  1
 X   0  -1  -2  -1  -1  -1  -1  -1  -1  -1  -1   0  -1  -2  -1  -1   0   0  -1  -2  -1
 Y  -2  -3  -4  -3  -2   4  -3   2   0  -1   0   1  -2  -3  -1  -1  -2  -1  -1   3  -1   9
 Z  -1   2  -3   1   5  -4  -2   0  -4   1  -2  -2   0  -1   4   0   0  -1  -3  -2  -1  -2   5
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum45)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -1   4
 C  -1  -2  12
@@ -582,10 +613,13 @@ W  -2  -4  -5  -4  -3   1  -2  -3  -2  -2  -2  -2  -4  -3  -2  -2  -4  -3  -3  1
 X   0  -1  -2  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1   0   0  -1  -2  -1
 Y  -2  -2  -3  -2  -2   3  -3   2   0  -1   0   0  -2  -3  -1  -1  -2  -1  -1   3  -1   8
 Z  -1   2  -3   1   4  -3  -2   0  -3   1  -2  -1   0  -1   4   0   0  -1  -3  -2  -1  -2   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum50)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -2   5
 C  -1  -3  13
@@ -609,10 +643,13 @@ W  -3  -5  -5  -5  -3   1  -3  -3  -3  -3  -2  -1  -4  -4  -1  -3  -4  -3  -3  1
 X  -1  -1  -2  -1  -1  -2  -2  -1  -1  -1  -1  -1  -1  -2  -1  -1  -1   0  -1  -3  -1
 Y  -2  -3  -3  -3  -2   4  -3   2  -1  -2  -1   0  -2  -3  -1  -1  -2  -2  -1   2  -1   8
 Z  -1   2  -3   1   5  -4  -2   0  -3   1  -3  -1   0  -1   4   0   0  -1  -3  -2  -1  -2   5
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum55)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -2   5
 C  -1  -3  13
@@ -636,10 +673,13 @@ W  -3  -5  -5  -5  -3   1  -3  -3  -3  -3  -2  -1  -4  -4  -1  -3  -4  -3  -3  1
 X  -1  -1  -2  -1  -1  -2  -2  -1  -1  -1  -1  -1  -1  -2  -1  -1  -1   0  -1  -3  -1
 Y  -2  -3  -3  -3  -2   4  -3   2  -1  -2  -1   0  -2  -3  -1  -1  -2  -2  -1   2  -1   8
 Z  -1   2  -3   1   5  -4  -2   0  -3   1  -3  -1   0  -1   4   0   0  -1  -3  -2  -1  -2   5
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum60)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 B  -2   4
 C   0  -3   9
@@ -663,10 +703,13 @@ W  -3  -4  -2  -4  -3   1  -2  -2  -2  -3  -2  -1  -4  -4  -2  -3  -3  -2  -3  1
 X   0  -1  -2  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -2  -1  -1   0   0  -1  -2  -1
 Y  -2  -2  -2  -3  -2   3  -3   2  -1  -2  -1  -1  -2  -3  -1  -2  -2  -2  -1   2  -1   6
 Z  -1   1  -3   1   4  -3  -2   0  -3   1  -2  -1   0  -1   3   0   0  -1  -2  -2  -1  -2   3
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum62)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 B  -2   4
 C   0  -3   9
@@ -690,10 +733,13 @@ W  -3  -4  -2  -4  -3   1  -2  -2  -3  -3  -2  -1  -4  -4  -2  -3  -3  -2  -3  1
 X   0  -1  -2  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -2  -1  -1   0   0  -1  -2  -1
 Y  -2  -3  -2  -3  -2   3  -3   2  -1  -2  -1  -1  -2  -3  -1  -2  -2  -2  -1   2  -1   7
 Z  -1   1  -3   1   4  -3  -2   0  -3   1  -3  -1   0  -1   3   0   0  -1  -2  -3  -1  -2   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum65)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 B  -2   4
 C   0  -3   9
@@ -717,10 +763,13 @@ W  -3  -4  -2  -5  -3   1  -3  -2  -2  -3  -2  -2  -4  -4  -2  -3  -3  -3  -3  1
 X  -1  -1  -2  -1  -1  -2  -2  -1  -1  -1  -1  -1  -1  -2  -1  -1  -1  -1  -1  -2  -1
 Y  -2  -3  -2  -3  -2   3  -3   2  -1  -2  -1  -1  -2  -3  -2  -2  -2  -2  -1   2  -1   7
 Z  -1   1  -4   1   4  -3  -2   0  -3   1  -3  -2   0  -1   3   0   0  -1  -2  -3  -1  -2   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum70)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 B  -2   4
 C  -1  -4   9
@@ -744,10 +793,13 @@ W  -3  -4  -3  -5  -4   1  -3  -2  -3  -3  -2  -2  -4  -4  -2  -3  -3  -3  -3  1
 X  -1  -1  -2  -2  -1  -2  -2  -1  -1  -1  -1  -1  -1  -2  -1  -1  -1  -1  -1  -3  -1
 Y  -2  -3  -3  -4  -3   3  -4   2  -1  -2  -1  -1  -2  -3  -2  -2  -2  -2  -2   2  -2   7
 Z  -1   0  -4   1   4  -4  -2   0  -3   1  -3  -2   0  -1   3   0   0  -1  -3  -3  -1  -2   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum75)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 B  -2   4
 C  -1  -4   9
@@ -771,10 +823,13 @@ W  -3  -5  -3  -5  -4   1  -3  -2  -3  -4  -2  -2  -4  -5  -2  -3  -3  -3  -3  1
 X  -1  -2  -2  -2  -1  -2  -2  -1  -2  -1  -1  -1  -1  -2  -1  -1  -1  -1  -1  -3  -1
 Y  -2  -3  -3  -4  -3   3  -4   2  -2  -2  -1  -2  -3  -4  -2  -2  -2  -2  -2   2  -2   7
 Z  -1   0  -4   1   4  -4  -2   0  -4   1  -3  -2   0  -2   3   0   0  -1  -3  -3  -1  -3   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum80)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -2   4
 C  -1  -4   9
@@ -798,10 +853,13 @@ W  -3  -5  -3  -6  -4   0  -4  -3  -3  -4  -2  -2  -4  -5  -3  -4  -4  -4  -3  1
 X  -1  -2  -3  -2  -1  -2  -2  -2  -2  -1  -2  -1  -1  -2  -1  -1  -1  -1  -1  -3  -1
 Y  -2  -3  -3  -4  -3   3  -4   2  -2  -3  -2  -2  -3  -4  -2  -3  -2  -2  -2   2  -2   7
 Z  -1   0  -4   1   4  -4  -3   0  -4   1  -3  -2   0  -2   3   0   0  -1  -3  -4  -1  -3   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum85)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -2   4
 C  -1  -4   9
@@ -825,10 +883,13 @@ W  -3  -5  -4  -6  -4   0  -4  -3  -3  -5  -3  -2  -5  -5  -3  -4  -4  -4  -3  1
 X  -1  -2  -3  -2  -1  -2  -2  -2  -2  -1  -2  -1  -2  -2  -1  -2  -1  -1  -1  -3  -2
 Y  -3  -4  -3  -4  -4   3  -5   2  -2  -3  -2  -2  -3  -4  -2  -3  -2  -2  -2   2  -2   7
 Z  -1   0  -5   1   4  -4  -3   0  -4   1  -4  -2  -1  -2   4   0  -1  -1  -3  -4  -1  -3   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum90)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -2   4
 C  -1  -4   9
@@ -852,10 +913,13 @@ W  -4  -6  -4  -6  -5   0  -4  -3  -4  -5  -3  -2  -5  -5  -3  -4  -4  -4  -3  1
 X  -1  -2  -3  -2  -2  -2  -2  -2  -2  -1  -2  -1  -2  -2  -1  -2  -1  -1  -2  -3  -2
 Y  -3  -4  -4  -4  -4   3  -5   1  -2  -3  -2  -2  -3  -4  -3  -3  -3  -2  -3   2  -2   8
 Z  -1   0  -5   0   4  -4  -3   0  -4   1  -4  -2  -1  -2   4   0  -1  -1  -3  -4  -1  -3   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.blosum95)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -3   4
 C  -1  -4   9
@@ -879,10 +943,13 @@ W  -4  -6  -4  -6  -5   0  -5  -3  -4  -5  -3  -2  -5  -5  -3  -4  -4  -4  -3  1
 X  -1  -2  -3  -2  -2  -2  -3  -2  -2  -1  -2  -2  -2  -3  -1  -2  -1  -1  -2  -4  -2
 Y  -3  -4  -4  -5  -4   3  -5   1  -2  -3  -2  -3  -3  -5  -3  -3  -3  -3  -3   2  -2   8
 Z  -1   0  -5   0   4  -4  -3   0  -4   0  -4  -2  -1  -2   4  -1  -1  -2  -3  -4  -1  -4   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.feng)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   6
 C   2   6
 D   4   1   6
@@ -903,10 +970,13 @@ T   5   2   2   3   1   2   2   3   4   2   3   4   4   3   3   5   6
 V   5   2   3   4   4   4   1   5   3   5   4   2   3   2   2   2   3   6
 W   2   3   0   1   3   3   1   2   1   4   3   0   2   1   2   2   1   3   6
 Y   2   3   2   1   5   2   3   3   1   3   2   3   2   2   1   3   2   3   3   6
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.fitch)
         self.assertEqual(len(mat), 171)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   3
 C   1   3
 E   1   1   3
@@ -925,10 +995,13 @@ U   1   1   1   2   2   1   1   2   1   1   2   2   2   2   3
 V   2   2   1   2   1   1   2   2   1   1   1   1   1   1   2   3
 W   1   1   2   2   1   1   1   2   2   1   0   1   2   0   2   2   3
 Y   2   2   1   1   1   1   2   1   1   1   1   2   2   2   2   2   1   3
-   A   C   E   F   H   I   L   M   N   O   Q   R   S   T   U   V   W   Y""")
+   A   C   E   F   H   I   L   M   N   O   Q   R   S   T   U   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.genetic)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 C  -1   5
 D   1  -1   4
@@ -949,10 +1022,13 @@ T   0  -1  -2  -2  -2  -2  -1   0   1  -1   0   0   1  -1   0   1   4
 V   1  -2   1   1   1   1  -2   1  -2   1   1  -2  -2  -2  -2  -2  -2   4
 W  -2   4  -2  -3   0   1  -2  -2  -3   0  -2  -3  -1  -2   1   0  -2  -2   7
 Y  -2   2   2   0   2  -1   2  -1   0  -1  -2   2  -2   0  -1   0  -2  -2   0   6
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.gonnet)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   2
 C   0  11
 D   0  -3   4
@@ -973,10 +1049,13 @@ T   0   0   0   0  -2  -1   0   0   0  -1   0   0   0   0   0   1   2
 V   0   0  -2  -1   0  -3  -2   3  -1   1   1  -2  -1  -1  -2  -1   0   3
 W  -3  -1  -5  -4   3  -4   0  -1  -3   0  -1  -3  -5  -2  -1  -3  -3  -2  14
 Y  -2   0  -2  -2   5  -4   2   0  -2   0   0  -1  -3  -1  -1  -1  -1  -1   4   7
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.grant)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A 215
 C  20 215
 D  89  61 215
@@ -997,9 +1076,12 @@ T 157  66 130 150 112 156 168 126 137 123 134 150 177 173 144 157 215
 V 151  23  63  94 165 106 131 186 118 183 194  82 147 119 119  91 146 215
 W  67   0  34  63 175  31 100 154 105 154 148  41  68  85 114  38  87 127 215
 Y 103  21  55  93 193  68 132 182 130 179 179  72 105 116 138  71 123 160 178 215
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.ident)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   6
 C  -1   6
 D  -1  -1   6
@@ -1020,10 +1102,13 @@ T  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1   6
 V  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1   6
 W  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1   6
 Y  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1   6
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.johnson)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   6
 C  -3  16
 D  -1  -9   8
@@ -1044,10 +1129,13 @@ T   0  -6  -1   0  -5  -3  -3  -3   0  -4  -3   0  -2   0  -1   2   6
 V   0  -4  -5  -4  -1  -5  -3   3  -3   1   0  -5  -5  -3  -4  -4  -1   7
 W  -5  -9  -6  -7   3  -6  -4  -3  -5  -1   0  -6  -7  -8  -3  -6  -9  -4  15
 Y  -4  -7  -3  -3   3  -5   0  -2  -3  -2  -1  -1  -7  -5  -2  -3  -2  -1   2  10
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.levin)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   2
 C   0   2
 D   0   0   2
@@ -1068,10 +1156,13 @@ T   0   0   0   0  -1   0   0   0   0   0   0   0   0   0   0   0   2
 V   0   0  -1  -1   0  -1  -1   1  -1   1   0  -1  -1  -1  -1  -1   0   2
 W  -1  -1  -1  -1   0  -1  -1   0  -1   0   0  -1  -1  -1   0  -1  -1   0   2
 Y  -1  -1  -1  -1   1  -1   0   0  -1   0   0  -1  -1  -1  -1  -1  -1   0   0   2
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.mclach)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   8
 C   1   9
 D   3   1   8
@@ -1092,10 +1183,13 @@ T   3   2   3   4   1   2   4   3   3   3   3   3   3   3   3   5   8
 V   3   1   1   2   3   2   2   5   2   5   4   1   2   2   2   2   3   8
 W   1   2   0   1   6   1   3   3   1   3   1   0   0   2   3   3   2   2   9
 Y   1   1   1   2   6   0   4   3   1   3   2   2   0   1   2   3   1   3   6   9
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.miyata)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   1
 C   0   1
 D  -1  -2   1
@@ -1116,10 +1210,13 @@ T   0   0   0   0  -1   0   0   0   0  -1   0   0   0   0   0   0   1
 V   0   0  -2  -1   0  -1   0   0  -1   0   0  -1   0   0  -1   0   0   1
 W  -2  -2  -3  -2   0  -3  -1   0  -1   0   0  -3  -2  -2  -1  -3  -2  -1   1
 Y  -1  -1  -2  -1   0  -2  -1   0  -1   0   0  -2  -1  -1   0  -2  -1   0   0   1
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.nwsgappep)
         self.assertEqual(len(mat), 253)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   1
 B   0   1
 C   0   0   1
@@ -1142,10 +1239,13 @@ V   0   0   0   0   0   0   0   0   1   0   0   0   0   0   0   0   0   0   1
 W   0   0  -1  -1  -1   1  -1   0   0   0   0   0   0   0   0   1   0   0   0   1
 Y   0   0   1   0   0   1   0   0   0   0   0   0   0   0   0   0   0   0   0   1   1
 Z   0   0   0   0   1   0   0   0   0   0   0   0   0   0   1   0   0   0   0   0   0   1
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.pam120)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   3
 B   0   4
 C  -3  -6   9
@@ -1169,10 +1269,13 @@ W  -7  -6  -8  -8  -8  -1  -8  -3  -6  -5  -3  -6  -4  -7  -6   1  -2  -6  -8  1
 X  -1  -1  -4  -2  -1  -3  -2  -2  -1  -2  -2  -2  -1  -2  -1  -2  -1  -1  -1  -5  -2
 Y  -4  -3  -1  -5  -5   4  -6  -1  -2  -5  -2  -4  -2  -6  -5  -5  -3  -3  -3  -2  -3   8
 Z  -1   2  -7   3   4  -6  -2   1  -3  -1  -3  -2   0  -1   4  -1  -1  -2  -3  -7  -1  -5   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.pam180)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   3
 B   0   4
 C  -3  -6  13
@@ -1196,10 +1299,13 @@ W  -8  -7 -10  -9  -9   0  -9  -4  -7  -5  -3  -6  -5  -7  -6   2  -3  -7  -8  1
 X  -1  -1  -4  -1  -1  -3  -2  -1  -1  -1  -2  -1  -1  -1  -1  -2   0  -1  -1  -6  -1
 Y  -5  -4   0  -6  -6   7  -7   0  -2  -6  -2  -4  -2  -7  -6  -6  -4  -4  -4  -1  -3  11
 Z   0   3  -7   3   5  -7  -1   2  -3   0  -3  -2   1  -1   5   0  -1  -1  -3  -8  -1  -6   5
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.pam250)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   2
 B   0   3
 C  -2  -4  12
@@ -1223,10 +1329,13 @@ W  -6  -5  -8  -7  -7   0  -7  -3  -5  -3  -2  -4  -4  -6  -5   2  -2  -5  -6  1
 X   0  -1  -3  -1  -1  -2  -1  -1  -1  -1  -1  -1   0  -1  -1  -1   0   0  -1  -4  -1
 Y  -3  -3   0  -4  -4   7  -5   0  -1  -4  -1  -2  -2  -5  -4  -4  -3  -3  -2   0  -2  10
 Z   0   2  -5   3   3  -5   0   2  -2   0  -3  -2   1   0   3   0   0  -1  -2  -6  -1  -4   3
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.pam30)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   6
 B  -3   6
 C  -6 -12  10
@@ -1250,10 +1359,13 @@ W -13 -10 -15 -15 -17  -4 -15  -7 -14 -12  -6 -13  -8 -14 -13  -2  -5 -13 -15  1
 X  -3  -5  -9  -5  -5  -8  -5  -5  -5  -5  -6  -5  -3  -5  -5  -6  -3  -4  -5 -11  -5
 Y  -8  -6  -4 -11  -8   2 -14  -3  -6  -9  -7 -11  -4 -13 -12 -10  -7  -6  -7  -5  -7  10
 Z  -3   0 -14   1   6 -13  -5  -1  -6  -4  -7  -5  -3  -4   6  -4  -5  -6  -6 -14  -5  -9   6
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.pam300)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   2
 B   0   3
 C  -2  -5  15
@@ -1277,10 +1389,13 @@ W  -6  -6  -9  -7  -8   1  -8  -3  -6  -4  -2  -5  -5  -6  -5   3  -3  -6  -7  2
 X   0   0  -3  -1  -1  -2  -1   0  -1  -1  -1  -1   0  -1   0  -1   0   0   0  -4  -1
 Y  -4  -4   1  -5  -5   9  -6   0  -1  -5   0  -2  -2  -5  -4  -5  -3  -3  -3   0  -2  12
 Z   0   2  -6   3   3  -5   0   2  -2   1  -3  -2   1   0   3   0   0   0  -2  -6  -1  -5   3
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.pam60)
         self.assertEqual(len(mat), 276)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   5
 B  -2   5
 C  -5  -9   9
@@ -1304,10 +1419,13 @@ W -10  -8 -12 -11 -12  -3 -11  -5 -10  -8  -4  -9  -6 -10  -9   0  -4  -9 -11  1
 X  -2  -3  -6  -3  -3  -5  -3  -3  -3  -3  -4  -3  -2  -3  -3  -4  -2  -2  -3  -8  -3
 Y  -6  -5  -2  -8  -7   3 -10  -2  -4  -7  -5  -7  -3 -10  -8  -8  -5  -5  -5  -3  -5   9
 Z  -2   1 -10   2   5 -10  -3   0  -4  -2  -5  -4  -1  -2   6  -2  -3  -4  -5 -11  -3  -7   5
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.pam90)
         self.assertEqual(len(mat), 253)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 B  -1   4
 C  -3  -7   9
@@ -1330,10 +1448,13 @@ V   0  -4  -3  -4  -3  -4  -3  -4   3  -5   0   1  -4  -3  -4  -4  -3  -1   6
 W  -8  -7 -10  -9 -10  -2  -9  -4  -8  -6  -3  -7  -5  -8  -7   0  -3  -7  -9  13
 Y  -5  -4  -1  -6  -6   4  -8  -1  -3  -6  -3  -6  -2  -8  -6  -6  -4  -4  -4  -2   9
 Z  -1   2  -8   3   5  -8  -2   1  -3  -1  -4  -3   0  -2   5  -1  -2  -2  -3  -8  -6   5
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y   Z""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.rao)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A  16
 C  11  16
 D   9   8  16
@@ -1354,10 +1475,13 @@ T  10  10   9   8  10  10  10  10   9   9   8  10   8  10   9  11  16
 V   9   8   3   4  11   6   9  12   5  10   9   5   3   6   5   8  10  16
 W  11  11   6   7  11   8  10  11   7  11  10   8   6   9   7  10  11  11  16
 Y   9  10   7   6  10  10   9  10   7   9   8   8   8   8   7  11  11  10  11  16
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.risler)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   2
 C  -1   2
 D   0  -1   2
@@ -1378,10 +1502,13 @@ T   1  -1   0   1   0   0   0   1   1   1   0   1   0   1   1   2   2
 V   2  -1   0   1   0   0   0   2   1   2   0   1   0   1   1   1   1   2
 W   0  -1  -1  -1   0  -1  -1   0  -1   0  -1  -1  -1  -1   0   0  -1   0   2
 Y   0  -1   0   0   2   0   0   0   0   0   0   0  -1   0   0   0   0   0   0   2
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
         mat = SubsMat.SeqMat(MatrixInfo.structure)
         self.assertEqual(len(mat), 210)
-        self.checkMatrix(mat, """\
+        self.checkMatrix(
+            mat,
+            """\
 A   4
 C  -2  11
 D  -1  -7   6
@@ -1402,7 +1529,8 @@ T  -1  -5  -1   0  -3  -3  -2  -2   0  -3  -2   0  -1   0  -1   1   5
 V   0  -4  -4  -2  -1  -4  -2   2  -3   1   0  -4  -4  -2  -3  -3  -1   5
 W  -3  -6  -6  -6   2  -4  -3  -2  -3  -1  -2  -5  -4  -5  -2  -5  -5  -4  10
 Y  -3  -6  -3  -2   3  -3   0  -1  -2  -2  -1  -1  -6  -3  -1  -2  -2  -1   2   7
-   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""")
+   A   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   Y""",
+        )
 
     def test_sequence_matrix_make_entropy(self):
         blosum30 = SubsMat.SeqMat(MatrixInfo.blosum30)
@@ -1411,7 +1539,9 @@ Y  -3  -6  -3  -2   3  -3   0  -1  -2  -2  -1  -1  -6  -3  -1  -2  -2  -1   2
 
     def test_sequence_matrix_str(self):
         blosum30 = SubsMat.SeqMat(MatrixInfo.blosum30)
-        self.assertEqual(str(blosum30), """\
+        self.assertEqual(
+            str(blosum30),
+            """\
 A   4
 B   0   5
 C  -3  -2  17
@@ -1435,7 +1565,8 @@ W  -5  -5  -2  -4  -1   1   1  -5  -3  -2  -2  -3  -7  -3  -1   0  -3  -5  -3  2
 X   0  -1  -2  -1  -1  -1  -1  -1   0   0   0   0   0  -1   0  -1   0   0   0  -2  -1
 Y  -4  -3  -6  -1  -2   3  -3   0  -1  -1   3  -1  -4  -2  -1   0  -2  -1   1   5  -1   9
 Z   0   0   0   0   5  -4  -2   0  -3   1  -1  -1  -1   0   4   0  -1  -1  -3  -1   0  -2   4
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
 
     def test_sequence_matrix_operations(self):
         blosum90 = SubsMat.SeqMat(MatrixInfo.blosum90)
@@ -1445,7 +1576,9 @@ Z   0   0   0   0   5  -4  -2   0  -3   1  -1  -1  -1   0   4   0  -1  -1  -3  -
         self.assertEqual(seqmatdiff, -321)
         # multiplication
         seqmatmul = blosum90 * blosum30
-        self.assertEqual(str(seqmatmul), """\
+        self.assertEqual(
+            str(seqmatmul),
+            """\
 A  20
 B   0  20
 C   3   8 153
@@ -1469,11 +1602,14 @@ W  20  30   8  24   5   0  -4  15  12  10   6   6  35  15   3   0  12  20   9 22
 X   0   2   6   2   2   2   2   2   0   0   0   0   0   2   0   2   0   0   0   6   2
 Y  12  12  24   4   8   9  15   0   2   3  -6   2  12   8   3   0   6   2  -3  10   2  72
 Z   0   0   0   0  20  16   6   0  12   1   4   2   1   0  16   0   1   1   9   4   0   6  16
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
 
         # Addition
         seqmatadd = blosum90 + blosum30
-        self.assertEqual(str(seqmatadd), """\
+        self.assertEqual(
+            str(seqmatadd),
+            """\
 A   9
 B  -2   9
 C  -4  -6  26
@@ -1497,7 +1633,8 @@ W  -9 -11  -6 -10  -6   1  -3  -8  -7  -7  -5  -5 -12  -8  -4  -4  -7  -9  -6  3
 X  -1  -3  -5  -3  -3  -3  -3  -3  -2  -1  -2  -1  -2  -3  -1  -3  -1  -1  -2  -5  -3
 Y  -7  -7 -10  -5  -6   6  -8   1  -3  -4   1  -3  -7  -6  -4  -3  -5  -3  -2   7  -3  17
 Z  -1   0  -5   0   9  -8  -5   0  -7   2  -5  -3  -2  -2   8   0  -2  -2  -6  -5  -1  -5   8
-   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""")
+   A   B   C   D   E   F   G   H   I   K   L   M   N   P   Q   R   S   T   V   W   X   Y   Z""",
+        )
 
     def test_two_mat_relative_entropy(self):
         blosum90 = SubsMat.SeqMat(MatrixInfo.blosum90)
@@ -1514,7 +1651,10 @@ Z  -1   0  -5   0   9  -8  -5   0  -7   2  -5  -3  -2  -2   8   0  -2  -2  -6  -
             correlation = SubsMat.two_mat_correlation(blosum90, blosum30)
             self.assertAlmostEqual(correlation, 0.878, places=3)
         except ValueError as err:
-            if "TRAVIS_CPU_ARCH" in os.environ and os.environ["TRAVIS_CPU_ARCH"] == "s390x":
+            if (
+                "TRAVIS_CPU_ARCH" in os.environ
+                and os.environ["TRAVIS_CPU_ARCH"] == "s390x"
+            ):
                 print("Known failure on the s390x architecture.")
             else:
                 raise err
