@@ -21,10 +21,12 @@ from Bio import pairwise2
 
 if pairwise2.rint == pairwise2._python_rint:
     from Bio import MissingExternalDependencyError
-    raise MissingExternalDependencyError("Missing or non-compiled file: "
-                                         "'cpairwise2'")
+
+    raise MissingExternalDependencyError(
+        "Missing or non-compiled file: 'cpairwise2'"
+    )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
